﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.ComponentModel;
using System.Collections.ObjectModel;

namespace TimeLineSimpleSample
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();      
            DataContext = new ViewModel();
        }
    }

    public class Data : INotifyPropertyChanged
    {
        private DateTime time;

        public DateTime DueDate
        {
            get { return time; }
            set { time = value; PropChanged("Time"); }
        }

        private TimeSpan dur;

        public TimeSpan Duration
        {
            get { return dur; }
            set { dur = value; PropChanged("Duration"); }
        }


        private string title;

        public string Title
        {
            get { return title; }
            set { title = value; PropChanged("Title"); }
        }


        private string dec;

        public string Details
        {
            get { return dec; }
            set { dec = value; PropChanged("Details"); }
        }

        public DateTime Time
        {
            get
            {
                return DueDate.AddHours(Duration.TotalHours * -1); 
            }
        }


        public event PropertyChangedEventHandler PropertyChanged;

        public void PropChanged(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }

    }

    public class ViewModel : INotifyPropertyChanged
    {
        public ObservableCollection<Data> Data { get; set; }

        private double _myScroll;
        public double MyScroll
        {
            get
            {
                return _myScroll;
            }
            set
            {
                if(value != _myScroll)
                {
                    _myScroll = value;
                    PropChanged("MyScroll");
                    Console.WriteLine("MyScroll=" + _myScroll);
                }
            }
        }

        private double _myScale;
        public double MyScale
        {
            get
            {
                return _myScale;
            }
            set
            {
                if (value != _myScale)
                {
                    _myScale = value;
                    PropChanged("MyScale");
                    Console.WriteLine("MyScale="+_myScale);
                }
            }
        }

        public ViewModel()
        {
            Data = new ObservableCollection<Data>();
            Random r = new Random();

            for (int i = 0; i < 5; i++)
            {
                int data = r.Next(100) + 10;
                Data.Add(new Data
                {
                    Title = "Data " + i,
                    Details = "Data Details " + DateTime.Now.AddDays(data).ToString(),
                    DueDate = DateTime.Now.AddDays(data),
                    Duration = new TimeSpan(10, 0, 0, 0)
                });
            }

            //Here you should cacluculate the values for the MyScroll and MyScale Proeperties.

            MyScroll = .3;
            MyScale = .3;
        }


        public event PropertyChangedEventHandler PropertyChanged;

        public void PropChanged(string name)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(name));
        }
    }
}